@@ -1,6 +1,8 @@
 package UnRTF;
 use Modern::Perl;
-use Moose;
+use Moo;
+use Types::Standard qw(Str);
+use IPC::Cmd qw(run can_run);
 
 =head1 NAME
 
@@ -25,19 +27,22 @@ Copyright (C) 2013 Joenio Costa
 
 =cut
 
-has file => (is => 'rw', isa => 'Str', required => 1);
+has file => (is => 'rw', isa => Str, required => 1);
+
+sub BUILD {
+  die "Could not find unrtf command" unless can_run('unrtf');
+}
 
 sub unrtf {
-  open STDERR, '>', '/dev/null';
-  open(UNRTF, "unrtf @_ |") or die $!;
-  local $/ = undef;
-  my $OUTPUT = <UNRTF>;
-  close UNRTF;
-  $OUTPUT;
+  my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf ) =
+    run( command => [ 'unrtf', @_ ], verbose => 0 );
+  die "unrtf failure: @{[ join '', @$stderr_buf  ]}" if ! $success;
+  return join '', @$stdout_buf;
 }
 
 sub convert {
   my ($self, %args) = @_;
+  return '' unless $args{format};
   unrtf("--$args{format}", $self->file);
 }
 
